@@ -7,6 +7,12 @@ from .consumer_factory import ConsumerFactory
 from .consumer_parameter import ConsumerParmeters
 from .producer_parameter import ProducerParmeters
 from .connection_parameter import ConnectionParmeters
-from .logging_helper import  set_debug_level
-
+from .logging_helper import set_debug_level
 
+__all__ = [Client,
+           ProducerFactory,
+           ConsumerFactory,
+           ConsumerParmeters,
+           ProducerParmeters,
+           ConnectionParmeters,
+           set_debug_level]
